complete -c fyi -x -s a -l app-name                          -d "app-name, typically used for the icon, unless --icon is used"
complete -c fyi -r -s i -l icon                              -d "notification icon, either a symbolic name or a file"
complete -c fyi -x -s u -l urgency  -a "low normal critical" -d "notification urgency"
complete -c fyi -x -s c -l category                          -d "notification category"
complete -c fyi -x -s r -l replaces                          -d "update an existing notification"
complete -c fyi -x -s t -l expire-time                       -d "notification timeout, in milliseconds"
complete -c fyi -x -s C -l close                             -d "close an existing notification"
complete -c fyi -x -s A -l action                            -d "add an action to display (NAME:LABEL)"
complete -c fyi -x -s H -l hint                              -d "add a custom hint (TYPE:NAME:VALUE)"
complete -c fyi         -l transient                         -d "show a transient notification"
complete -c fyi    -s p -l print-id                          -d "print the notification ID"
complete -c fyi    -s T -l print-token                       -d "print the activation token"
complete -c fyi    -s R -l print-reason                      -d "print the reason the notification was closed"
complete -c fyi    -s w -l wait                              -d "wait for notification to close"
complete -c fyi -x      -l image-data                        -d "raw RGBA image data, sets the 'image-data' hint"
complete -c fyi -x      -l image-size                        -d "dimensions of the image loaded by --image-data"
complete -c fyi         -l server-info                       -d "print server name and version"
complete -c fyi         -l server-capabilities               -d "print server capabilities"
complete -c fyi    -s v -l version                           -d "show the version number and quit"
complete -c fyi    -s h -l help                              -d "show help message and quit"
